@@ -5,7 +5,7 @@ use warnings;
 
 use CGI ':standard';
 
-print header;
+print header(-charset => 'utf-8');
 print do { local $/; <DATA> };
 
 __DATA__
